Struct lunatic_twitchax_patch::ap::Config
source · pub struct Config<AP: AbstractProcess> { /* private fields */ }Expand description
AbstractProcess startup configuration.
Available configuration options:
die_if_link_dies- Sets if link deaths should be caught.
The Config struct can also be used to acquire a self reference with
self_ref to send messages to itself during the
initialization process.
Implementations
sourceimpl<AP: AbstractProcess> Config<AP>
impl<AP: AbstractProcess> Config<AP>
sourcepub fn die_if_link_dies(&self, die: bool)
pub fn die_if_link_dies(&self, die: bool)
If set to true, each link death will trigger the
handle_link_death handler.
If set to false and a linked process dies, the AbstractProcess
will die too.
Default value is false.
sourcepub fn self_ref(&self) -> ProcessRef<AP>
pub fn self_ref(&self) -> ProcessRef<AP>
Get a reference to the running AbstractProcess.