Struct lunatic_twitchax_patch::protocol::ProtocolCapture
source · pub struct ProtocolCapture<C> { /* private fields */ }Expand description
A value that the protocol captures from the parent process.
A protocol needs to capture more information from the parent than just the
value passed in by the user (capture). For a protocol to work it needs to
have a reference to the parent, so it knows where to send messages to. And
it needs a unique tag inside the parent so that protocol messages don’t mix
with other messages received by the parent.