pub struct Statement { /* private fields */ }
Available on crate feature sqlite only.
Prepared SQL statement.

Implementations

source

impl Statement

source

pub fn bind(self, value: impl Into<Value>) -> Self

Bind based on an incrementing index.

source

pub fn bind_named( self, name: impl Into<String>, value: impl Into<Value> ) -> Self

Bind based on a name.

source

pub fn execute(self) -> Vec<Vec<Value>>

Executes the query returning all rows collected as a Vec.

source

pub fn execute_iter(self) -> QueryIter

Executes the query returning an iterator over rows.

The query will not be executed until the iter is iterated upon.