pub struct WithTimeout<T> { /* private fields */ }
Modifies T so that all functions on it will return a timeout.

It’s used to time out calls such as ProcessRef::shutdown, ProcessRef::request, etc.

Implementations

source

impl<T: AbstractProcess> WithTimeout<ProcessRef<T>>

source

pub fn from(timeout: Duration, item: ProcessRef<T>) -> Self

source

pub fn shutdown(&self) -> Result<(), Timeout>
where T::Serializer: CanSerialize<ShutdownMessage<T::Serializer>> + CanSerialize<()>,

Shuts the AbstractProcess down.

The function will only wait for the duration of the specified timeout on the process to shut down, before returning Err(Timeout).

source

pub fn request<R: 'static>(&self, request: R) -> Result<T::Response, Timeout>
where T: RequestHandler<R>, T::Serializer: CanSerialize<R> + CanSerialize<T::Response> + CanSerialize<RequestMessage<R, T::Response, T::Serializer>>,

Make a request to the process.

The function will only wait for the duration of the specified timeout on the response, before returning Err(Timeout).

source

pub fn deferred_request<R: 'static>( &self, request: R ) -> Result<T::Response, Timeout>
where T: DeferredRequestHandler<R>, T::Serializer: CanSerialize<R> + CanSerialize<T::Response> + CanSerialize<RequestMessage<R, T::Response, T::Serializer>>,

Make a deferred request to the process.

The function will only wait for the duration of the specified timeout on the response, before returning Err(Timeout).