Trait lunatic_twitchax_patch::function::process::NoLink
source · pub trait NoLink { }Expand description
A marker trait expressing that a process can be spawned from this type without linking.
This is used to forbid Protocol to use the
spawn functions and only allow usage of spawn_link functions.