Struct lunatic_twitchax_patch::sqlite::Statement
source · pub struct Statement { /* private fields */ }Available on crate feature
sqlite only.Expand description
Prepared SQL statement.
Implementations
sourceimpl Statement
impl Statement
sourcepub fn bind_named(
self,
name: impl Into<String>,
value: impl Into<Value>
) -> Self
pub fn bind_named( self, name: impl Into<String>, value: impl Into<Value> ) -> Self
Bind based on a name.
sourcepub fn execute(self) -> Vec<Vec<Value>>
pub fn execute(self) -> Vec<Vec<Value>>
Executes the query returning all rows collected as a Vec.
sourcepub fn execute_iter(self) -> QueryIter ⓘ
pub fn execute_iter(self) -> QueryIter ⓘ
Executes the query returning an iterator over rows.
The query will not be executed until the iter is iterated upon.