Struct lunatic_twitchax_patch::time::WithTimeout
source · pub struct WithTimeout<T> { /* private fields */ }Expand description
Modifies T so that all functions on it will return a timeout.
It’s used to time out calls such as ProcessRef::shutdown,
ProcessRef::request, etc.
Implementations
sourceimpl<T: AbstractProcess> WithTimeout<ProcessRef<T>>
impl<T: AbstractProcess> WithTimeout<ProcessRef<T>>
pub fn from(timeout: Duration, item: ProcessRef<T>) -> Self
sourcepub fn shutdown(&self) -> Result<(), Timeout>
pub fn shutdown(&self) -> Result<(), Timeout>
Shuts the AbstractProcess down.
The function will only wait for the duration of the specified timeout on
the process to shut down, before returning Err(Timeout).
sourcepub fn request<R: 'static>(&self, request: R) -> Result<T::Response, Timeout>where
T: RequestHandler<R>,
T::Serializer: CanSerialize<R> + CanSerialize<T::Response> + CanSerialize<RequestMessage<R, T::Response, T::Serializer>>,
pub fn request<R: 'static>(&self, request: R) -> Result<T::Response, Timeout>where
T: RequestHandler<R>,
T::Serializer: CanSerialize<R> + CanSerialize<T::Response> + CanSerialize<RequestMessage<R, T::Response, T::Serializer>>,
Make a request to the process.
The function will only wait for the duration of the specified timeout on
the response, before returning Err(Timeout).
sourcepub fn deferred_request<R: 'static>(
&self,
request: R
) -> Result<T::Response, Timeout>where
T: DeferredRequestHandler<R>,
T::Serializer: CanSerialize<R> + CanSerialize<T::Response> + CanSerialize<RequestMessage<R, T::Response, T::Serializer>>,
pub fn deferred_request<R: 'static>(
&self,
request: R
) -> Result<T::Response, Timeout>where
T: DeferredRequestHandler<R>,
T::Serializer: CanSerialize<R> + CanSerialize<T::Response> + CanSerialize<RequestMessage<R, T::Response, T::Serializer>>,
Make a deferred request to the process.
The function will only wait for the duration of the specified timeout on
the response, before returning Err(Timeout).